Module: Panda::Core

Defined in:
lib/panda/core.rb,
lib/panda/core/seo.rb,
lib/panda/core/debug.rb,
lib/panda/core/media.rb,
lib/panda/core/engine.rb,
lib/panda/core/railtie.rb,
lib/panda/core/version.rb,
lib/panda/core/sluggable.rb,
app/models/panda/core/tag.rb,
lib/panda/core/middleware.rb,
lib/panda/core/rake_tasks.rb,
app/models/panda/core/user.rb,
lib/panda/core/asset_loader.rb,
lib/panda/core/configuration.rb,
lib/panda/core/notifications.rb,
app/models/panda/core/current.rb,
app/models/panda/core/tagging.rb,
lib/panda/core/authentication.rb,
app/components/panda/core/base.rb,
app/models/panda/core/presence.rb,
lib/panda/core/module_registry.rb,
lib/panda/core/oauth_providers.rb,
lib/panda/core/search_registry.rb,
lib/panda/core/widget_registry.rb,
app/models/panda/core/breadcrumb.rb,
app/components/panda/core/UI/card.rb,
lib/panda/core/component_registry.rb,
app/components/panda/core/UI/badge.rb,
app/helpers/panda/core/form_helper.rb,
app/models/panda/core/feature_flag.rb,
app/models/panda/core/user_session.rb,
lib/panda/core/engine/route_config.rb,
lib/panda/core/navigation_registry.rb,
lib/panda/core/permission_registry.rb,
app/components/panda/core/UI/button.rb,
app/helpers/panda/core/asset_helper.rb,
app/models/panda/core/file_category.rb,
app/models/panda/core/user_activity.rb,
app/services/panda/core/file_parser.rb,
app/builders/panda/core/form_builder.rb,
app/models/panda/core/import_session.rb,
lib/panda/core/seeds/file_categories.rb,
lib/panda/core/services/base_service.rb,
lib/panda/core/engine/autoload_config.rb,
lib/panda/core/engine/omniauth_config.rb,
app/helpers/panda/core/sessions_helper.rb,
lib/panda/core/engine/generator_config.rb,
lib/panda/core/engine/importmap_config.rb,
lib/panda/core/shared/generator_config.rb,
app/models/concerns/panda/core/has_uuid.rb,
app/models/concerns/panda/core/taggable.rb,
app/models/panda/core/application_record.rb,
app/services/panda/core/file_categorizer.rb,
app/services/panda/core/presence_service.rb,
lib/panda/core/shared/inflections_config.rb,
app/models/concerns/panda/core/importable.rb,
app/models/concerns/panda/core/searchable.rb,
app/models/panda/core/file_categorization.rb,
app/helpers/panda/core/feature_flag_helper.rb,
app/services/panda/core/csv_import_service.rb,
app/constraints/panda/core/admin_constraint.rb,
app/models/concerns/panda/core/has_metadata.rb,
app/services/panda/core/invite_user_service.rb,
lib/generators/panda/core/install_generator.rb,
lib/panda/core/engine/view_component_config.rb,
app/helpers/panda/core/active_storage_helper.rb,
app/components/panda/core/admin/tag_component.rb,
app/services/panda/core/attach_avatar_service.rb,
lib/panda/core/engine/admin_controller_config.rb,
lib/panda/core/engine/pending_migrations_check.rb,
app/components/panda/core/admin/panel_component.rb,
app/components/panda/core/admin/table_component.rb,
app/components/panda/core/admin/button_component.rb,
app/controllers/concerns/panda/core/authorizable.rb,
app/controllers/panda/core/admin/base_controller.rb,
app/controllers/panda/core/admin/tags_controller.rb,
app/components/panda/core/admin/callout_component.rb,
app/components/panda/core/admin/heading_component.rb,
app/components/panda/core/admin/sidebar_component.rb,
app/components/panda/core/admin/tab_bar_component.rb,
app/components/panda/core/shared/footer_component.rb,
app/components/panda/core/shared/header_component.rb,
app/controllers/panda/core/admin/files_controller.rb,
app/controllers/panda/core/admin/users_controller.rb,
app/controllers/panda/core/application_controller.rb,
lib/panda/core/engine/sqlite_schema_compatibility.rb,
lib/panda/core/testing/support/system/chrome_path.rb,
app/components/panda/core/admin/dropdown_component.rb,
app/controllers/panda/core/admin/search_controller.rb,
app/components/panda/core/admin/container_component.rb,
app/components/panda/core/admin/slideover_component.rb,
app/components/panda/core/admin/tag_badge_component.rb,
app/components/panda/core/admin/tag_input_component.rb,
lib/panda/core/testing/support/system/cuprite_setup.rb,
app/components/panda/core/admin/breadcrumb_component.rb,
app/components/panda/core/admin/code_block_component.rb,
app/components/panda/core/admin/form_error_component.rb,
app/components/panda/core/admin/form_input_component.rb,
app/components/panda/core/admin/login_form_component.rb,
app/components/panda/core/admin/pagination_component.rb,
app/components/panda/core/admin/search_bar_component.rb,
app/components/panda/core/admin/statistics_component.rb,
app/components/panda/core/admin/tags_panel_component.rb,
app/controllers/panda/core/admin/sessions_controller.rb,
app/controllers/panda/core/admin/settings_controller.rb,
lib/panda/core/subscribers/authentication_subscriber.rb,
app/components/panda/core/admin/breadcrumbs_component.rb,
app/components/panda/core/admin/empty_state_component.rb,
app/components/panda/core/admin/form_footer_component.rb,
app/components/panda/core/admin/form_select_component.rb,
app/components/panda/core/admin/main_layout_component.rb,
app/components/panda/core/admin/page_header_component.rb,
app/components/panda/core/admin/prose_panel_component.rb,
app/controllers/panda/core/admin/dashboard_controller.rb,
lib/panda/core/testing/support/authentication_helpers.rb,
lib/panda/core/testing/support/system/cuprite_helpers.rb,
app/components/panda/core/admin/file_gallery_component.rb,
app/components/panda/core/admin/filter_pills_component.rb,
app/components/panda/core/admin/form_section_component.rb,
app/components/panda/core/admin/secret_field_component.rb,
app/components/panda/core/admin/user_display_component.rb,
app/controllers/panda/core/admin/my_profile_controller.rb,
app/components/panda/core/admin/delete_button_component.rb,
app/components/panda/core/admin/flash_message_component.rb,
app/components/panda/core/admin/user_activity_component.rb,
app/controllers/concerns/panda/core/admin_authorization.rb,
app/components/panda/core/admin/attribute_diff_component.rb,
app/components/panda/core/admin/dropdown_button_component.rb,
app/components/panda/core/admin/navigation/item_component.rb,
app/controllers/panda/core/admin/editor/search_controller.rb,
app/controllers/panda/core/admin/feature_flags_controller.rb,
app/controllers/panda/core/admin/test_sessions_controller.rb,
lib/panda/core/testing/support/system/system_test_helpers.rb,
lib/panda/core/testing/support/authentication_test_helpers.rb,
app/components/panda/core/admin/search_filter_bar_component.rb,
app/controllers/panda/core/admin/file_categories_controller.rb,
app/controllers/panda/core/admin/import_sessions_controller.rb,
lib/panda/core/testing/support/system/ferrum_console_logger.rb,
app/components/panda/core/admin/navigation/sub_item_component.rb,
app/controllers/panda/core/admin/my_profile/logins_controller.rb,
app/components/panda/core/admin/contributors_summary_component.rb,
app/components/panda/core/admin/navigation/user_menu_component.rb,
app/components/panda/core/admin/dashboard_default_content_component.rb,
app/components/panda/core/admin/my_profile/connected_account_component.rb

Defined Under Namespace

Modules: ActiveStorageHelper, Admin, AdminAuthorization, AssetHelper, Authentication, AuthenticationHelpers, AuthenticationTestHelpers, Authorizable, Debug, FeatureFlagHelper, FormHelper, Generators, HasMetadata, HasUUID, Importable, Media, Middleware, Notifications, OAuthProviders, RakeTasks, SEO, Searchable, Seeds, Services, SessionsHelper, Shared, Sluggable, SqliteSchemaCompatibility, Subscribers, Taggable, Testing, UI Classes: AdminConstraint, ApplicationController, ApplicationRecord, AssetLoader, AttachAvatarService, Base, Breadcrumb, CSVImportService, ChartkickAssetMiddleware, ComponentRegistry, Configuration, Current, Engine, FeatureFlag, FileCategorization, FileCategorizer, FileCategory, FileParser, FormBuilder, ImportSession, InviteUserService, ModuleRegistry, NavigationRegistry, PermissionRegistry, Presence, PresenceService, Railtie, SearchRegistry, SearchableConfig, Tag, Tagging, User, UserActivity, UserSession, WidgetRegistry

Constant Summary collapse

ACRONYMS =

Single source of truth for acronyms used across all Panda gems. Referenced by Shared::InflectionsConfig (engine initializer) and applied eagerly below for generator/CLI contexts.

%w[CMS CSV SEO AI URL UUID].freeze
ADMIN_SESSION_KEY =

Session key for storing authenticated Panda Core admin user ID Namespaced to avoid conflicts with host application user sessions

:panda_core_user_id
VERSION =
"1.1.1"

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.configObject



304
305
306
# File 'lib/panda/core/configuration.rb', line 304

def config
  @config ||= Configuration.new
end

Class Method Details

.configure {|config| ... } ⇒ Object

Yields:



308
309
310
# File 'lib/panda/core/configuration.rb', line 308

def configure
  yield(config)
end

.reset_config!Object Also known as: reset_configuration!



312
313
314
# File 'lib/panda/core/configuration.rb', line 312

def reset_config!
  @config = Configuration.new
end

.rootObject



20
21
22
# File 'lib/panda/core.rb', line 20

def self.root
  File.expand_path("../..", __FILE__)
end