Module: Panda::Core::FormHelper
- Defined in:
- app/helpers/panda/core/form_helper.rb
Instance Method Summary collapse
-
#panda_form_with(**options) ⇒ Object
Wraps form_with to apply consistent admin form styling across all Panda engines.
Instance Method Details
#panda_form_with(**options) ⇒ Object
Wraps form_with to apply consistent admin form styling across all Panda engines. Sets the custom FormBuilder and applies default CSS classes for padding/layout.
8 9 10 11 12 |
# File 'app/helpers/panda/core/form_helper.rb', line 8 def panda_form_with(**, &) [:builder] = Panda::Core::FormBuilder [:class] = ["block visible", [:class]].compact.join(" ") form_with(**, &) end |